package com.huijy.management.service;

import java.util.List;
import com.huijy.management.domain.EarlyWarning;

/**
 * 预警信息Service接口
 *
 * @author luobo
 * @date 2021-09-12
 */
public interface IEarlyWarningService
{
    /**
     * 查询预警信息
     *
     * @param earlyWarningId 预警信息主键
     * @return 预警信息
     */
    public EarlyWarning selectEarlyWarningByEarlyWarningId(Long earlyWarningId);

    /**
     * 查询预警信息列表
     *
     * @param earlyWarning 预警信息
     * @return 预警信息集合
     */
    public List<EarlyWarning> selectEarlyWarningList(EarlyWarning earlyWarning);

    /**
     * 新增预警信息
     *
     * @param earlyWarning 预警信息
     * @return 结果
     */
    public int insertEarlyWarning(EarlyWarning earlyWarning);

    /**
     * 修改预警信息
     *
     * @param earlyWarning 预警信息
     * @return 结果
     */
    public int updateEarlyWarning(EarlyWarning earlyWarning);

    /**
     * 批量删除预警信息
     *
     * @param earlyWarningIds 需要删除的预警信息主键集合
     * @return 结果
     */
    public int deleteEarlyWarningByEarlyWarningIds(Long[] earlyWarningIds);

    /**
     * 删除预警信息信息
     *
     * @param earlyWarningId 预警信息主键
     * @return 结果
     */
    public int deleteEarlyWarningByEarlyWarningId(Long earlyWarningId);

    public Integer updateSendFlag(Long earlyWarningId,String sendFlag,Long adminId);
}
